@@ -80,6 +80,10 @@ USING_INTERNAL_DISPLAY_AS_MAIN_ON_OSX = False
 
 FILLING_SPACE = 103
 
+STDOUT_FILENAME = "stdout.txt"
+EXECUTION_LOG_FILENAME = "execution_log.txt"
+ZMQ_LOG_FILENAME = "zmq_log.txt"
+
 
 def internal_display_used_as_main_on_osx() -> bool:
         '''
@@ -106,17 +110,6 @@ def internal_display_used_as_main_on_osx() -> bool:
         return internal_display_as_main
 
 
-
-def init_dir(dirname):
-    """Initializes directory with given name"""
-    if not os.path.isdir(dirname):
-        original_umask = os.umask(0)
-        try:
-            os.makedirs(dirname, 0o777)
-        finally:
-            os.umask(original_umask)
-
-
 def log(filename, line, time=True):
     """Log to file"""
     with open(filename, "a+", encoding="utf-8") as file:
@@ -143,7 +136,7 @@ class TaskWrapper():
         self.trigger = trigger
         self.priority = priority
 
-    def execute(self):
+    def execute(self, logdir: str):
         """_summary_
 
         Returns:
@@ -157,22 +150,18 @@ class TaskWrapper():
         # info.dwFlags = subprocess.STARTUPINFO()
         # info.wShowWindow = SW_MINIMIZE
 
-        log_time = datetime.strftime(datetime.now(), '%Y%m%d-%H%M%S')
-        log_dir = os.path.join(self.cwd, "logs", self.name, log_time)
-        stdout_filename = os.path.join(log_dir, "stdout.txt")
-        zmq_log_filename = os.path.join(log_dir, "zmq_log.txt")
-        execution_log_filename = os.path.join(log_dir, "execution_log.txt")
-        init_dir(log_dir)
-
-        with open(stdout_filename, "w+", encoding="utf-8") as stdout_logfile:
+        stdout_filename = os.path.join(logdir, STDOUT_FILENAME)
+        with open(stdout_filename, "w+", encoding="utf-8") as stdout_file:
             # check if python command exists on current machine and has version 3.x, otherwise run python3
             status, output = subprocess.getstatusoutput('python --version')
             python_command = "python" if status == 0 and output.startswith("Python 3") else "python3"
-            process = subprocess.Popen([python_command, filepath, log_dir],  # pass log_dir as command line arg
-                                       cwd=self.cwd,
-                                       stdout=stdout_logfile,
-                                       shell=False)
-            return process, stdout_filename, zmq_log_filename, execution_log_filename
+            process = subprocess.Popen(
+                [python_command, filepath, logdir],  # pass log_dir as cli arg
+                cwd=self.cwd,
+                stdout=stdout_file,
+                shell=False
+            )
+            return process
     def __str__(self) -> str:
         """str format for TaskWrapper"""
         if self.execution_type == 'SC':
@@ -201,10 +190,13 @@ class Task():
         self.standalone = standalone
 
         self._data = {}  # task-specific data
-        self.log_time = datetime.strftime(datetime.now(), '%Y%m%d-%H%M%S')
-        self.log_dir = self._init_log_dir()
-        self.execution_logfile = sys.argv[1] if not standalone else os.path.join(self.log_dir, "execution_log.txt")
-        self.zmq_logfile = sys.argv[1] if not standalone else os.path.join(self.log_dir, "zmq_log.txt")
+        if standalone:
+            log_time = datetime.strftime(datetime.now(), '%Y-%m-%dT%H%M%S')
+            self.logdir = os.path.join(cwd, 'logs', name, log_time)
+            os.makedirs(self.logdir, exist_ok=True)
+        else:
+            self.logdir = sys.argv[1]
+
         self.zmq_client_socket = self._get_zmq_client_socket()
         self.last_box_location = None
         self.error = False
@@ -222,14 +214,6 @@ class Task():
         socket.connect(f"tcp://localhost:{ZMQ_PORT}")
         return socket
 
-    def _init_log_dir(self):
-        if not self.standalone:
-            return sys.argv[1]
-        path =  os.path.join(self.cwd, 'logs', self.name, self.log_time)
-        if not os.path.exists(path):
-            os.makedirs(path)
-        return path
-
     def add_step(self, step):
         """Add a step to the current list of steps.
 
@@ -274,7 +258,7 @@ class Task():
         """Function that logs the most important things after a failure
         """
         self.error = True
-        screenshot_path = os.path.join(self.log_dir, "last_screenshot.png")
+        screenshot_path = os.path.join(self.logdir, "last_screenshot.png")
         try:
             img = PngImageFile(os.path.join(self.cwd,".temp_screenshot.png"))
             img.save(screenshot_path)
@@ -316,11 +300,11 @@ class Task():
 
     def _log_execution(self, line, time=True):
         """Log the execution process"""
-        log(self.execution_logfile, line, time)
+        log(f"{self.logdir}/{EXECUTION_LOG_FILENAME}", line, time)
 
     def _log_zmq(self, line, time=True):
         """Log ZMQ communication"""
-        log(self.zmq_logfile, line, time)
+        log(f"{self.logdir}/{ZMQ_LOG_FILENAME}", line, time)
 
     def _send_zmq_msg(self, type, msg):
         msg = {"type": type, "msg": msg}
