@@ -240,7 +240,19 @@ def _screenshot_osx(image_filename=None, region=None):
         tmp_filename = 'screenshot%s.png' % (datetime.now().strftime('%Y-%m%d_%H-%M-%S-%f'))
     else:
         tmp_filename = image_filename
-    subprocess.call(['screencapture', '-x', tmp_filename])
+
+    tmp_filename_parts = tmp_filename.split("/")
+    if tmp_filename_parts[-1].startswith("."):
+        # the screencapture command does not work with hidden files, so
+        # temporarily remove the dot from the filename, take screenshot and
+        # rename file to hidden filename
+        tmp_filename_parts[-1] = tmp_filename_parts[-1][1:]
+        tmp_filename_unhidden = "/".join(tmp_filename_parts)
+        subprocess.call(["screencapture", "-x", tmp_filename_unhidden])
+        subprocess.call(["mv", tmp_filename_unhidden, tmp_filename])
+    else:
+        subprocess.call(["screencapture", "-x", tmp_filename])
+
     img = Image.open(tmp_filename)
 
     if region is not None:
